pub enum BeaconEngineMessage<Payload: PayloadTypes> {
NewPayload {
payload: Payload::ExecutionData,
tx: Sender<Result<PayloadStatus, BeaconOnNewPayloadError>>,
},
RethNewPayload {
payload: Payload::ExecutionData,
tx: Sender<Result<(PayloadStatus, NewPayloadTimings), BeaconOnNewPayloadError>>,
},
ForkchoiceUpdated {
state: ForkchoiceState,
payload_attrs: Option<Payload::PayloadAttributes>,
version: EngineApiMessageVersion,
tx: Sender<RethResult<OnForkChoiceUpdated>>,
},
}std only.Expand description
A message for the beacon engine from other components of the node (engine RPC API invoked by the consensus layer).
Variants
NewPayload
Message with new payload.
Fields
payload: Payload::ExecutionDataThe execution payload received by Engine API.
tx: Sender<Result<PayloadStatus, BeaconOnNewPayloadError>>The sender for returning payload status result.
RethNewPayload
Message with new payload used by reth_newPayload endpoint.
Waits for persistence, execution cache, and sparse trie locks before processing, and returns detailed timing breakdown alongside the payload status.
Fields
payload: Payload::ExecutionDataThe execution payload received by Engine API.
tx: Sender<Result<(PayloadStatus, NewPayloadTimings), BeaconOnNewPayloadError>>The sender for returning payload status result and timing breakdown.
ForkchoiceUpdated
Message with updated forkchoice state.
Fields
state: ForkchoiceStateThe updated forkchoice state.
version: EngineApiMessageVersionThe Engine API Version.
tx: Sender<RethResult<OnForkChoiceUpdated>>The sender for returning forkchoice updated result.