ExecutableTxIterator

Trait ExecutableTxIterator 

pub trait ExecutableTxIterator<Evm>: ExecutableTxTuple
where Self::Tx: ExecutableTxFor<Evm, Recovered = Self::Recovered>, Evm: ConfigureEvm,
{ type Recovered: RecoveredTx<<<Evm as ConfigureEvm>::Primitives as NodePrimitives>::SignedTx> + Send + Sync; }
Available on crate feature std only.
Iterator over executable transactions.

See also ExecutableTxTuple for the raw transaction iterator and converter this extension trait builds on.

Required Associated Types

type Recovered: RecoveredTx<<<Evm as ConfigureEvm>::Primitives as NodePrimitives>::SignedTx> + Send + Sync

HACK: for some reason, this duplicated AT is the only way to enforce the inner Recovered: Send + Sync bound. Effectively alias for Self::Tx::Recovered.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl<T, Evm> ExecutableTxIterator<Evm> for T
where Evm: ConfigureEvm, T: ExecutableTxTuple, <T as ExecutableTxTuple>::Tx: ExecutableTxFor<Evm>, <<T as ExecutableTxTuple>::Tx as ExecutableTxParts<<<<Evm as ConfigureEvm>::BlockExecutorFactory as BlockExecutorFactory>::EvmFactory as EvmFactory>::Tx, <<Evm as ConfigureEvm>::Primitives as NodePrimitives>::SignedTx>>::Recovered: Send + Sync,



type Recovered = <<T as ExecutableTxTuple>::Tx as ExecutableTxParts<<<<Evm as ConfigureEvm>::BlockExecutorFactory as BlockExecutorFactory>::EvmFactory as EvmFactory>::Tx, <<Evm as ConfigureEvm>::Primitives as NodePrimitives>::SignedTx>>::Recovered